;
; ds1302.asm - DS1302 clock chip handler
;
; Written by
;  Kajtar Zsolt <soci@c64.rulez.org>
;
;    This file is part of IDEDOS the IDE64 disk operating system
;    See README for copyright notice.
;
;    This program is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    This program is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with this program; if not, write to the Free Software
;    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
;
;--------------------------------------
; LWOP_get_cmos_setup (B0)
; LWOP_read_clock (B2)
;
;--------------------------------------
LWOP_get_cmos_setup .proc
		lda #%11111111		;read ram burst command
		jsr cmos_start
		tax
lp		pha
		jsr cmos_read_byte	;read byte from RAM
		sta setup_params_exp,x	;buffer
		pla
		eor setup_params_exp,x	;buffer
		inx
		cpx #setup_crc_exp-setup_params_exp+1
		bne lp
		jsr cmos_end
		cmp #"I"
		bne cmos_default	;error in stored bytes
		rts			;C=1 ok
;---

cmos_default	.proc
		clc			;C=0 err
		ldx #setup_crc_exp-setup_params_exp-1
lp		lda setup_default,x
		sta setup_params_exp,x
		dex
		bpl lp
		rts
setup_default	.byte DRIVE0,DRIVE0,DRIVE1,PC0,LCD0,FLOPPY8,FLOPPY9,FLOPPY10,FLOPPY11,6,14,14,CMOS_TURBO|CMOS_DOS_WEDGE,%11111111,$00,127,127
		.pend
;--------------------------------------
write_ram_burst	.proc
		clc
                jsr cmos_writeprotect
		lda #%11111110		;data write brust
		jsr cmos_start
		tax
		lda #"I"
lp		tay
		lda setup_params_exp,x
		jsr cmos_send_byte
		tya
		eor setup_params_exp,x
		inx
		cpx #setup_crc_exp-setup_params_exp
		bne lp
		jsr cmos_send_byte	;crc
                sta kill_port
		sec

cmos_writeprotect .proc
		php
		lda #%10001110  	;write control reg
		jsr cmos_start
                plp
                ror
                jsr cmos_send_byte
                geq cmos_end
                .pend
;--------------------------------------
LWOP_read_clock	.proc
		lda #%10111111		;burst read
		jsr cmos_start
                ldx #$ff

		jsr cmos_read_clk	;sec
		cmp #$60
		bcs read_clock_err
		jsr cmos_read_clk	;min
		cmp #$60
		bcs read_clock_err
		jsr cmos_read_clk	;hour
		cmp #$24
		bcs read_clock_err
		jsr cmos_read_clk	;date
		beq read_clock_err
		cmp #$32
		bcs read_clock_err
		jsr cmos_read_clk	;month
		beq read_clock_err
		cmp #$13
		bcs read_clock_err
		jsr cmos_read_clk	;day of week
		beq read_clock_err
		cmp #$08
		bcs read_clock_err
		jsr cmos_read_clk	;year

cmos_end	.proc
		ldx #$00		;reset
		stx kill_port
		rts
		.pend

cmos_read_clk	.proc
		inx
		jsr cmos_read_byte
                sta sec_exp,x
                rts
		.pend
;--------------------------------------
; Default time 00:00:00 1.1.2000
;--------------------------------------
read_clock_err	.proc
		ldx #6
lp		lda date_default,x
		sta sec_exp,x
		dex
		bpl lp
		gmi cmos_end
date_default	.byte $00,$00,$00,$01,$01,$07,$00
		.pend
;--------------------------------------
cmos_start	.proc
		ldx #$02
		stx kill_port		;UNreset
cmos_send_byte	.proc
		jsr *+3
		jsr *+3
		jsr *+3
		sta clock_port		; bit 0
		lsr a
		rts
		.pend
;------------------
cmos_read_byte	.proc
		jsr *+3
		jsr *+3
		jsr *+3
		lda clock_port		; bit 1
		lsr a
		tya
		ror a
		tay
		rts
		.pend
